@@ -1,7 +1,7 @@
 """
 The MIT License (MIT)
 
-Copyright (c) 2018 Losant IoT, Inc.
+Copyright (c) 2020 Losant IoT, Inc.
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
@@ -22,6 +22,9 @@ OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 SOFTWARE.
 """
 
+
+import json
+
 """ Module for Losant API Files wrapper class """
 # pylint: disable=C0301
 
@@ -122,7 +125,7 @@ class Files(object):
         *  {boolean} _embedded - Return embedded resources in response
 
         Responses:
-        *  201 - Successfully created file and returned a post url to respond with (https://api.losant.com/#/definitions/fileUploadPostResp)
+        *  201 - Successfully created file and returned a post url to respond with (https://api.losant.com/#/definitions/fileUploadPostResponse)
 
         Errors:
         *  400 - Error if malformed request (https://api.losant.com/#/definitions/error)
